@@ -28,9 +28,10 @@ def test_content(response):
 def test_command_line_interface():
     """Test the CLI."""
     runner = CliRunner()
-    result = runner.invoke(cli.main)
+    result = runner.invoke(cli.cli)
     assert result.exit_code == 0
-    assert 'koapy.cli.main' in result.output
-    help_result = runner.invoke(cli.main, ['--help'])
+    assert 'Usage' in result.output
+    help_result = runner.invoke(cli.cli, ['--help'])
     assert help_result.exit_code == 0
     assert '--help  Show this message and exit.' in help_result.output
+    assert 'serve' in help_result.output
